============
Installation
============

To install the `pyquations` Python package, run the following command.

.. code-block:: bash

    pip install pyquations


To upgrade to the latest version, use the following command.

.. code-block:: bash

    pip install --upgrade pyquations
